@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- python -*-
-# Time-stamp: <2004-11-28 11:39:04 graham>
+# Time-stamp: <2005-11-09 05:59:02 Graham>
 
 # Program to generate bash_completion function for wajig.
 # It runs 'wajig command' and analyzes the output to build 'wajig' in the
@@ -89,7 +89,7 @@ _wajig()
         cur=${COMP_WORDS[COMP_CWORD]}
         prev=${COMP_WORDS[COMP_CWORD-1]}
 
-        if [ "$COMP_CWORD" == "2" ]; then
+        if [ "$COMP_CWORD" -ge "2" ]; then
            COMPREPLY=($( compgen -W "$(apt-cache pkgnames "$cur")" -- $cur ) )
         elif [[ "$cur" == -* ]]; then
             COMPREPLY=($( compgen -W \''''
