@@ -1297,6 +1297,7 @@ def do_whichpkg(filename):
     #
     print "%-59s %-17s" % ("File Path", "Package")
     print "="*59 + "-" + "="*17
+    print "INSTALLED"
     sys.stdout.flush()
 
     #
@@ -1313,10 +1314,11 @@ def do_whichpkg(filename):
               "| grep -v '^diversion by ' " +\
               "| awk -F: '{printf(\"%-59s %-17s\\n\", $2, $1)}'"
     perform.execute(command)
-
     #
     # Now obtain the information from the Debian server
     #
+    print "-"*77
+    print "AVAILABLE"
     results = tempfile.mktemp()
     filename = filename.replace('+', '%2B')
 
@@ -1335,11 +1337,16 @@ def do_whichpkg(filename):
         #
         # Multiple pages of output
         #
-        command = "cat " + results + " | " +\
-                  "egrep -v " +\
-                  "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
-                  "egrep -v 'page=' | " +\
-                  "perl -p -e 's|<[^>]*>||g;s|<[^>]*$||g;s|^[^<]*>||g;'"
+        # 071104 gjw - It appears we don't get multiple pages
+        # with the new HTML format, so maybe I don't need
+        # to fix this one up. Just do a cat so that if we do
+        # then someone is bound to notice!!!!
+        command = "cat " + results #+ " | " #+\
+                  # HTML FORMAT CHANGED Oct 2007
+                  # "egrep -v " +\
+                  # "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
+                  # "egrep -v 'page=' | " +\
+                  # "perl -p -e 's|<[^>]*>||g;s|<[^>]*$||g;s|^[^<]*>||g;'"
         perform.execute(command)
         #
         # Loop over the other pages
@@ -1367,10 +1374,18 @@ def do_whichpkg(filename):
         # A single page of output
         #
         command = "cat " + results + " | " +\
-                  "egrep -v " +\
-                  "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
-                  "perl -p -e 's|<[^>]*>||g;s|<[^>]*$||g;s|^[^<]*>||g;'"
+                  "awk 'BEGIN { RS = \"</tr>\" } " +\
+                  "/\"keyword\"/ { print $0 }' | " +\
+                  "lynx -stdin -dump -nonumbers | " +\
+                  "egrep -v '^$' | " +\
+                  "sed 's|, |,|' | " +\
+                  "awk '{printf(\"%-59s %-17s\\n\", $1, $2)}'"
+                  # 071104 gjw HTML FORMAT CHANGED
+                  # "egrep -v " +\
+                  # "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
+                  # "perl -p -e 's|<[^>]*>||g;s|<[^>]*$||g;s|^[^<]*>||g;'"
         perform.execute(command)
+    print "-"*77
 
     if os.path.exists(results): os.remove(results)
 
