@@ -37,9 +37,7 @@ the Free Software Foundation; either version 2 of the License, or
 
 On Debian systems, it may be found in /usr/share/common-licenses/GPL.
 
-Wajig development takes place at http://sarovar.org/projects/wajig.
-
-Fuller documentation can be found at http://www.togaware.com/wajig.
+Fuller documentation can be found at http://wajig.togaware.com/.
 """
 
 #
@@ -111,6 +109,7 @@ Run LIST-COMMANDS for a complete list of commands.
  auto-clean     Remove superseded .deb files from the download cache
  auto-download  Do an update followed by a download of all updated packages
  auto-install   Perform an install without asking questions (non-interactive)
+ auto-remove    Remove packages installed automatically as dependencies
  available      List versions of packages available for installation
  bug            Check reported bugs in package using the Debian Bug Tracker
  build          Retrieve/unpack sources and build .deb for the named packages
@@ -118,6 +117,7 @@ Run LIST-COMMANDS for a complete list of commands.
  changelog      Retrieve latest changelog for the package
  clean          Remove all deb files from the download cache
  commands       List all the JIG commands and one line descriptions for each
+ contents       List the contents of a package file
  daily-upgrade  Perform an update then a dist-upgrade
  dependents     List of packages which depend/recommend/suggest the package
  describe       One line description of packages (-v and -vv for more detail)
@@ -139,6 +139,7 @@ Run LIST-COMMANDS for a complete list of commands.
  help           Print documentation (detail depends on --verbose)
  hold           Place listed packages on hold so they are not upgraded
  init           Initialise or reset the JIG archive files
+ info           List the information contained in a package file
  install        Install (or upgrade) one or more packages or .deb files
  installr       Install package and associated recommended packages
  installrs      Install package and recommended and suggested packages
@@ -222,6 +223,7 @@ Run LIST-COMMANDS for a complete list of commands.
  update-usb-ids Updates the local list of USB ids from the internet master list
  upgrade        Upgrade all of the installed packages or just those listed
  verify		Check the md5sums of a package.
+ version	Show the current version of wajig.
  versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
  whichpkg       Find the package that supplies the given command or file 
@@ -267,8 +269,8 @@ piece of writing, especially in rhyme, a farce in verse, or a ballad.
 For WAJIG, `wa' is Japanese, indicating `harmony' and `team spirit and
 unity.'
 
-Development of WAJIG happens at wajig.sarovar.org and is sponsored and
-supported by Togaware, an Australian based Debian GNU/Linux company.
+Development of WAJIG is sponsored and supported by Togaware, an
+Australian based Debian GNU/Linux company.
 
 WAJIG DOCUMENTATION
 
@@ -312,7 +314,7 @@ directly if you prefer.
 
 Online information about wajig includes Karl Schmidt's rpm to
 apt-get/dpkg page at http://xtronics.com/reference/rpm2apt-dpkg.htm,
-and my own guide at http://survivor.sarovar.org/wajig.html.
+and my own guide at http://wajig.togaware.com/.
 
 HISTORY: MOTIVATIONS FOR WAJIG
 
@@ -396,119 +398,7 @@ $ wajig -v help
 All wajig commands:
 
  addcdrom       Add a CD-ROM to the list of available sources of packages
- auto-alts      Mark the alternative to be auto set (using set priorities)
- auto-clean     Remove superseded deb files from the download cache
- auto-download  Do an update followed by a download of all updated packages
- auto-install   Perform an install without asking questions (non-interactive)
- available      List versions of packages available for installation
- bug            Check reported bugs in package using the Debian Bug Tracker
- build          Retrieve/unpack sources and build .deb for the named packages
- build-depend   Retrieve packages required to build listed packages
- changelog      Retrieve latest changelog for the package
- clean          Remove all deb files from the download cache
- commands       List all the JIG commands and one line descriptions for each
- daily-upgrade  Perform an update then a dist-upgrade
- dependents     List of packages which depend/recommend/suggest the package
- describe       One line description of packages (-v and -vv for more detail)
- describe-new   One line description of new packages
- detail         Provide a detailed description of package (describe -vv)
- detail-new     Provide a detailed description of new packages (describe -vv)
- dist-upgrade   Upgrade to new distribution (installed and new rqd packages)
- docs           Equivalent to help with -verbose=2
- download       Download package files ready for an install
- file-download  Download packages listed in file ready for an install
- file-install   Install packages listed in a file
- file-remove    Remove packages listed in a file
- find-file      Search for a file within installed packages
- find-pkg       Search for an unofficial Debian package at apt-get.org
- fix-configure  Perform dpkg --configure -a (to fix interrupted configure)
- fix-install    Perform apt-get -f install (to fix broken dependencies)
- fix-missing    Perform apt-get --fix-missing upgrade
- force          Install packages and ignore file overwrites and depends
- help           Print documentation (detail depends on --verbose)
- hold           Place listed packages on hold so they are not upgraded
- init           Initialise or reset the JIG archive files
- install        Install (or upgrade) one or more packages or .deb files
- installr       Install package and associated recommended packages
- installrs      Install package and recommended and suggested packages
- installs       Install package and associated suggested packages
- install/dist   Install packages from specified distribution
- integrity      Check the integrity of installed packages (through checksums)
- large          List size of all large (>10MB) installed packages
- last-update    Identify when an update was last performed
- list           List the status and description of installed packages
- list-all       List a one line description of every known package
- list-alts      List the objects that can have alternatives configured
- list-cache     List the contents of the download cache
- list-commands  List all the JIG commands and one line descriptions for each
- list-daemons   List the daemons that JIG can start/stop/restart
- list-files     List the files that are supplied by the named package
- list-hold      List those packages on hold
- list-installed List packages (with optional argument substring) installed
- list-log       List the contents of the install/remove log file (filtered)
- list-names     List all known packages or those containing supplied string
- list-orphans   List libraries not required by any installed package
- list-section   List packages that belong to a specific section
- list-sections  List the sections that are available
- list-status    Same as list but only prints first two columns, not truncated
- list-wide      Same as list but avoids truncating package names
- local-dist-upgrade Dist-upgrade using packages already downloaded
- local-upgrade  Upgrade using packages already downloaded, but not any others
- locate	        Search for a file within installed packages
- move           Move packages in the download cache to a local Debian mirror
- new            List packages that became available since last update
- news           Obtain the latest news about the package
- new-upgrades   List packages newly available for upgrading
- non-free       List installed packages that do not meet the DFSG
- orphans        List libraries not required by any installed package
- package        Generate a .deb file for an installed package
- policy         From preferences file show priorities/policy (available)
- purge          Remove one or more packages and configuration files
- purge-depend   Purge package and those it depend on and not required by others
- purge-orphans  Purge orphaned libraries (not required by installed packages)
- readme         Display the package's README file from /usr/share/doc
- recursive      Download package and any it depends on
- recommended    Install package and associated recommended packages
- reconfigure    Reconfigure the named installed packages or run gkdebconf
- reinstall      Reinstall each of the named packages
- reload         Reload daemon configs, e.g., gdm, apache (see list-daemons)
- remove         Remove one or more packages (see also purge)
- remove-depend  Remove package and its dependees not required by others
- remove-orphans Remove orphaned libraries (not required by installed packages)
- repackage      Generate a .deb file for an installed package
- reset          Initialise or reset the JIG archive files
- restart        Stop then start a daemon, e.g., gdm, apache (see list-daemons)
- rpm2deb        Convert a RedHat .rpm file to a Debian .deb file
- rpminstall     Install a RedHat .rpm package
- rpmtodeb       Convert a RedHat .rpm file to a Debian .deb file
- search         Search for packages containing listed words
- search-apt     Find local Debian archives suitable for sources.list
- setup          Configure the sources.list file which locates Debian archives
- show           Provide a detailed description of package [same as detail]
- showdistupgrade Trace the steps that a dist-upgrade would perform
- showinstall    Trace the steps that an install would perform
- showremove     Trace the steps that a remove would perform
- showupgrade    Trace the steps that an upgrade would perform
- size           Print out the size (in K) of all, or listed, installed packages
- sizes          Print out the size (in K) of all, or listed, installed packages
- source         Retrieve and unpack sources for the named packages
- start          Start a daemon, e.g., gdm, apache (see list-daemons)
- status         Show the version and available version of packages
- status-match   Show the version and available version of matching packages
- status-search  Show the version and available version of matching packages
- stop           Stop a daemon, e.g., gdm, apache (see list-daemons)
- suggested      Install package and associated suggested packages
- tasksel        Run the Gnome task selector to install groups of packages
- toupgrade      List packages with newer versions available for upgrading
- unhold         Remove listed packages from hold so they are again upgraded
- unofficial     Search for an unofficial Debian package at apt-get.org
- update         Update the list of downloadable packages
- update-alts    Update default alternative for things like x-window-manager
- upgrade        Upgrade all of the installed packages or just those listed
- verify		Check the md5sums of a package.
- versions       List version and distribution of (all) packages.
- whatis         A synonym for describe
- whichpkg       Find the package that supplies the given command or file 
+ ...
 
 Command line options:
 
