@@ -118,9 +118,38 @@ def execute(command, root=0, noquiet=0, display=1, pipe=0, langC = False):
         print command
     if root > 0:
         if setroot == "/usr/bin/sudo":
-            # If the command contains a pipe, and requires root,
-            # each part must be sudo.
+            #
+            # Bug #320126. Karl suggested that we use -v to preset the
+            # password, which also avoids mixing password failure
+            # with command failure but this causes password to be
+            # asked for even if the sudoers file indicates a password
+            # is not required. But this happens in only a few cases,
+            # like listnames (in user has no access to sources.list),
+            # hold, unhold. So should be sufferable.
+            #
+            if '|' in command and os.system(setroot + " -v"):
+                raise SystemExit("wajig: sudo authentication failed.")
+            #
+            # Bug #320126 noted the following is not good as is since
+            # the password is asked for multiple times in a pipe
+            # before it is cached.  It captures the case where the
+            # command contains a pipe, and requires root. Then each
+            # part is done as sudo.  TODO: It's not always true that
+            # root is required for each part!  E.g. HOLD doesn't need
+            # it: echo package hold | dpkg --set-selections
+            #
             command = setroot + " " + command.replace("|", "| %s " % setroot)
+            #
+            # Did try packaging the sudo up in a sh command. But then
+            # this loses the tuning of sudoers to just the APT commands.
+            # and also required /bin/sh to be NOPASSWD'ed if wanted
+            # password-less wajig.
+            #
+            # command = setroot + " sh -c '%s'" % command
+            #
+            # Decide to always require a password, even if sudoers
+            # says NOPASSWD. Only other alternative might be to store
+            # intermediate results in temporary files.
         else:
             if quiet == "" and user != "root":
                 print """
