@@ -60,6 +60,13 @@ def requires_one_arg(command, args, message):
         return False
     return True
 
+def requires_two_args(command, args, message):
+    if len(args) != 3:
+        print progname + ": Error: " + command.upper() + " requires " + message
+        finishup(1)
+        return False
+    return True
+
 def requires_opt_arg(command, args, message):
     if len(args) > 2:
         print progname + ": Error: " + command.upper() +\
@@ -249,6 +256,13 @@ def main():
             perform.set_teaching_level(teaching)
         elif o in ("-y", "--yes"):
             yes = " --yes "
+        # The --force-yes is a dangerous option that will cause apt to
+        # continue without prompting if it is doing something
+        # potentially harmful. It should not be used except in very
+        # special situations.  Using force-yes can potentially destroy
+        # your system! Configuration Item: APT::Get::force-yes.
+        # elif o in ("-Y", "--force-yes"):
+        #    yes = " --yes --force-yes"
         elif o in ("-n", "--noauth"):
             noauth = " --allow-unauthenticated "
         elif o == "-v":
@@ -283,8 +297,15 @@ def main():
     # Process the command. Lowercase it so that we allow any case
     # for commands and allow hyphens and underscores and slash.
     #
-    command = re.sub('-|_|/', '', string.lower(args[0]))
- 
+    # Need to check for install/sarge-backport and not convert the 
+    # part after the / (Bug##350944)
+    #
+    slash = args[0].find("/")
+    if slash == -1:
+        command = re.sub('-|_|/', '', string.lower(args[0]))
+    else:
+        command = re.sub('-|_|/', '', string.lower(args[0][:slash])) +\
+                  args[0][slash+1:]
     #
     # Provide help up front - don't need to initialise the system to give help
     #
@@ -341,7 +362,7 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "autoclean":
         if requires_no_args(command, args):
-            perform.execute("apt-get autoclean",root=1)
+            perform.execute("apt-get autoclean", root=1)
 
     elif command == "autoinstall":
         if requires_args(command, args, "a list of package names"):
@@ -349,6 +370,10 @@ def select_command(command, args, verbose, teaching):
                       perform.concat(args[1:])
             perform.execute(command, root=1)
 
+    elif command == "autoremove":
+        if requires_no_args(command, args):
+            perform.execute("apt-get autoremove", root=1)
+
     elif command == "available" or command == "avail":
         if requires_args(command, args, "a list of packages"):
             perform.execute("apt-cache policy " + perform.concat(args[1:]))
@@ -381,6 +406,10 @@ def select_command(command, args, verbose, teaching):
         if requires_no_args(command, args):
             perform.execute("apt-get clean",root=1)
 
+    elif command == "contents":
+        if requires_one_arg(command, args, "a filename"):
+            perform.execute("dpkg --contents " + args[1])
+
     elif command == "dailyupgrade":
         if requires_no_args(command, args):
             commands.do_update()
@@ -451,6 +480,11 @@ def select_command(command, args, verbose, teaching):
             #    perform.execute("apt-setup", root=1)
             perform.execute("editor /etc/apt/sources.list", root=1)
 
+    elif command == "extract":
+        if requires_two_args(command, args,
+                             "a filename and directory to extract into"):
+            perform.execute("dpkg --extract " + args[1] + " " + args[2])
+
     elif command == "filedownload" or \
          command == "downloadfile":
         if requires_one_arg(command, args, "a file name containing list of packages"):
@@ -504,6 +538,10 @@ def select_command(command, args, verbose, teaching):
             commands.do_hold(args[1:])
             # TODO Perhaps I can use map to "execute" over each package
 
+    elif command == "info":
+        if requires_one_arg(command, args, "a filename"):
+            perform.execute("dpkg --info " + args[1])
+
     elif command == "init":
         if requires_no_args(command, args):
             changes.reset_files()
@@ -533,9 +571,11 @@ def select_command(command, args, verbose, teaching):
 
     elif re.compile(r'install.*').match(command):
         # For example: install/unsable
-        if requires_args(command, args, "a list of packages, .deb files, or url"):
+        if requires_args(command, args,
+                         "a list of packages, .deb files, or url"):
             command = "apt-get --target-release %s install %s" %\
-                  (re.compile(r'install').sub("", command), perform.concat(args[1:]))
+                  (re.compile(r'install').sub("", command),
+                   perform.concat(args[1:]))
             perform.execute(command, root=1)
 
     elif command == "integrity":
@@ -607,8 +647,12 @@ def select_command(command, args, verbose, teaching):
             pr --columns=3 --omit-header")
 
     elif command == "listfiles":
-        if requires_one_arg(command, args, "the name of a single Debian package"):
-            perform.execute("dpkg --listfiles " + args[1])
+        if requires_one_arg(command, args,
+                            "the name of a single Debian package or deb file"):
+            if re.match(".*\.deb$", args[1]):
+                perform.execute("dpkg --contents " + args[1])
+            else:
+                perform.execute("dpkg --listfiles " + args[1])
 
     elif command == "listsection":
         if requires_one_arg(command, args, "the name of a Debian Section." +
@@ -663,6 +707,9 @@ def select_command(command, args, verbose, teaching):
             perform.execute("apt-get --no-download --ignore-missing " \
                             + "--show-upgraded upgrade", root=1)
 
+    elif command == "moo":
+        perform.execute("apt-get moo")
+
     elif command == "madison":
         perform.execute("apt-cache madison " + perform.concat(args[1:]))
 
@@ -776,7 +823,9 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "reload":
         if requires_one_arg(command, args, "name of service to " + command):
-            perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
+            perform.execute("/etc/init.d/" + args[1] + " " + command, root=1)
+            # Bug#426969
+            # perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
 
     elif command == "remove":
         if requires_args(command, args, "a list of packages"):
@@ -807,7 +856,9 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "restart":
         if requires_one_arg(command, args, "name of service to " + command):
-            perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
+            perform.execute("/etc/init.d/" + args[1] + " " + command, root=1)
+            # Bug#426969
+            # perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
 
     elif command == "rpminstall":
         if requires_one_arg(command, args, "a Red Hat package file name (.rpm)"):
@@ -818,6 +869,8 @@ def select_command(command, args, verbose, teaching):
             perform.execute("alien -d " + args[1], root=1)
 
     elif command == "search":
+        # Note that this uses a regular expression, thus libstdc++6
+        # finds nothing but libstdc..6 does.
         if requires_args(command, args, "a list of words to search for"):
             perform.execute("apt-cache search " + perform.concat(args[1:]))
 
@@ -861,7 +914,9 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "start":
         if requires_one_arg(command, args, "name of service to " + command):
-            perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
+            perform.execute("/etc/init.d/" + args[1] + " " + command, root=1)
+            # Bug#426969
+            # perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
 
     elif command == "status":
         commands.do_status(args[1:])
@@ -886,7 +941,9 @@ def select_command(command, args, verbose, teaching):
 
     elif command == "stop":
         if requires_one_arg(command, args, "name of service to " + command):
-            perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
+            perform.execute("/etc/init.d/" + args[1] + " " + command, root=1)
+            # Bug#426969
+            # perform.execute("invoke-rc.d " + args[1] + " " + command, root=1)
 
     elif command == "tasksel":
         if requires_no_args(command, args):
